@@ -15,7 +15,7 @@ use base (OS_CONF)[0];			## backward compatibility only
 our $VERSION;
 
 BEGIN {
-	$VERSION = '1.34';
+	$VERSION = '1.35';
 	eval { __PACKAGE__->bootstrap($VERSION) };
 }
 
@@ -266,9 +266,7 @@ sub bgread {
 	$self->errorstring( $handle->err );
 
 	my $reply = $self->_decode_result( $handle->result ) || return;
-
-	delete $reply->{id} unless $reply->{id};
-	$handle->query->{id} = $reply->_quid;
+	$handle->query->{id} = $reply->_quid;			# zero id replaced by random lie
 
 	$reply->print if $self->debug;
 	return $reply;
@@ -570,6 +568,7 @@ sub _decode_result {
 	my $buffer = $result->answer_packet || return;
 	my $packet = Net::DNS::Packet->decode( \$buffer );
 	$self->errorstring($@);
+	delete $packet->{id} unless $packet->{id};		# discard zero id
 	return $packet;
 }
 
